#! /bin/sh
#
# Simple little script which builds the .class files which are older
# than the .java files.
#
# Exit codes: 0 - Ok, 1 - bad options, 2 - compile errors, 3 - fatal errors
#
# Copyright (c) 1997, 1998
#      Transvirtual Technologies, Inc.  All rights reserved.
#
# See the file "license.terms" for information on usage and redistribution
# of this file.
#

if test "$*" = "" ; then
	echo "usage: makeJava options {java files|all}"
	echo "-srcdir path   where sources are placed (default is '.')"
	echo "-dstdir path   where compiled classes will be placed (default is 'lib')"
	echo "-force         don't check whether classes are newer than sources"
	echo "-unsafe        don't check whether classes are created"
	echo "-batch         compile all newer sources together (implies -unsafe)"
	echo "Use 'all' to compile all sources in java and kaffe directories"
	exit 1
fi

srcdir=.
dstdir=lib
alltopdirs="java kaffe"
batch=0
force=0
unsafe=0
otherargs=""
errorlist=""
batchlist=""

if test "$JAVAC" = "" ; then
	JAVAC="javac"
fi

if test "$JAVAC_CP" = "" ; then
	JAVAC_CP="$dstdir:$srcdir:$CLASSPATH:$srcdir/Klasses.jar"
fi

if test "$JFLAGS" = "" ; then
	JFLAGS="-classpath $JAVAC_CP -verbose"
fi

while test x$1 != x; do

case $1 in
-srcdir)
	if test x$2 = x; then
		echo argument to $1 missing
		exit 1
	fi
	srcdir=$2; shift; shift;;
-dstdir)
	if test x$2 = x; then
		echo argument to $1 missing
		exit 1
	fi
	dstdir=$2; shift; shift;;
-batch)
	batch=1; shift;;
-force)
	force=1; shift;;
-unsafe)
	unsafe=1; shift;;
-*)
	echo "Unknown option $1"; exit 1;;
*)
	if test x"$otherargs" = x; then
		otherargs="$1"
	else
		otherargs="$otherargs $1"
	fi
	shift;;
esac

done

if test x"$otherargs" = x; then
	echo "No files to compile"
	exit 1
elif test x"$otherargs" = xall; then
	files=`cd $srcdir; find $alltopdirs -type f -name \*.java -print`
else
	files="$*"
	addsrcdir=1
fi

for file in $files
do
	b=`echo $file | sed s/\\.java$//`
	jf=$srcdir/$b.java
	cf=$dstdir/$b.class
	docompile=0
	if test ! -f $cf ; then
		docompile=1
	elif test $force = 1 -o $cf -ot $jf ; then
		docompile=1
	fi
	if test "$docompile" = "1" ; then
		outdir=`dirname $cf`
		if test ! -d $outdir; then
			echo Creating directory $outdir
			mkdir -p $outdir
		fi
		if test $batch = 1; then
			if test x"$batchlist" = x; then
				batchlist="$jf"
			else
				batchlist="$batchlist $jf"
			fi
		else
			echo "Compiling $jf"
			$JAVAC $JFLAGS -d $dstdir $jf
			if test $? = 0; then
				if test -f $cf; then
					echo "done"
				elif test $unsafe = 0; then
					echo Fatal error while processing $jf
					echo belonging to `grep ^package $jf`
					exit 3
				fi
			else
				if test x"$errorlist" = x; then
					errorlist="$jf"
				else
					errorlist="$errorlist $jf"
				fi
				echo "not done"
			fi
		fi
	fi
done

if test $batch = 1; then
	echo "Compiling $batchlist"
	$JAVAC $JFLAGS -d $dstdir $batchlist
	if test $? = 0; then
		echo "done"
	else
		echo "not done"
	fi
elif test x"$errorlist" != x; then
	echo There were errors while compiling:
	echo $errorlist
	exit 2
else
	echo No errors encountered
fi
